@@ -3,7 +3,7 @@ package Import::Export;
 use Carp;
 use namespace::clean ();
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our %EX;
 
@@ -20,7 +20,7 @@ sub import {
 	return unless my @export = @_;
 	Carp::croak('define your %EX export hash')
 		unless (%EX) = %{"${pkg}::EX"};
-	
+
 	$options = pop @export if ref $export[-1];
 	$caller = $options->{-caller} if exists $options->{-caller};
 	my @exported = export($pkg, $caller, @export);
@@ -30,7 +30,7 @@ sub import {
 			$caller,
 			@exported
 		)
-		: namespace::clean->import(  # use p @export, { clean => 'import' }
+		: namespace::clean->import(  # use p @export, { clean => 1 }
 			-cleanee => $caller,
 			@exported
 		);
@@ -75,7 +75,7 @@ Import::Export - Exporting
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -102,6 +102,18 @@ Quick summary of what the module does.
 
 	use One qw/one/ { clean => 1 };
 
+	.....
+
+	package Lost
+
+	sub import {
+		...
+		require Found;
+		Found->import(qw/all/, { clean => 'import', -caller => $caller });
+		...
+	}
+
+
 =head2 import
 
 =head2 export
